==> getsocial_flutter_sdk-7.6.0.tar.gz: lib/communities/activity.dart <==
import '../common/media_attachment.dart';
import '../src/utils.dart';
import '../usermanagement/user.dart';
import 'activitybutton.dart';
import 'communitiesentity.dart';
import 'mention.dart';
import 'poll.dart';
import 'userreactions.dart';

/// Describe Activity object.
class GetSocialActivity {
  GetSocialActivity.fromJSON(Map<String, dynamic> json)
      : id = json['id'],
        text = json['text'],
        author = User.fromJSON(json['author']),
        attachments = Utils.createList(json['attachments'],
            (jsonMap) => MediaAttachment.fromJSON(jsonMap)),
        button = json['button'] == null
            ? null
            : ActivityButton.fromJSON(json['button']),
        type = json['type'],
        isAnnouncement = json['announcement'],
        commentsCount = json['commentsCount'],
        reactionsCount = Utils.createStringIntMap(json['reactionsCount']),
        myReactions = Utils.createStringList(json['myReactions']),
        reactions = Utils.createList(
            json['reactions'], (jsonMap) => UserReactions.fromJSON(jsonMap)),
        commenters = Utils.createList(
            json['commenters'], (jsonMap) => User.fromJSON(jsonMap)),
        properties = Utils.createStringStringMap(json['properties']),
        createdAt = json['createdAt'],
        mentions = Utils.createList(
            json['mentions'], (jsonMap) => Mention.fromJSON(jsonMap)),
        source = CommunitiesEntity.fromJSON(json['source']),
        status = json['status'],
        poll = json['poll'] == null ? null : Poll.fromJSON(json['poll']);

  String id;
  String? text;
  User author;
  List<MediaAttachment> attachments;
  ActivityButton? button;
  String type;
  bool isAnnouncement;
  int commentsCount;
  Map<String, int> reactionsCount;
  List<String> myReactions;
  List<UserReactions> reactions;
  List<User> commenters;
  Map<String, String> properties;
  int createdAt;
  List<Mention> mentions;
  CommunitiesEntity source;
  String status;
  Poll? poll;

  @override
  String toString() {
    var authorId = this.author.userId;
    return 'Activity{'
        'id: $id, '
        'text: $text,'
        'author: $authorId,'
        'mediaAttachments: $attachments,'
        'button: $button,'
        'type: $type,'
        'isAnnouncement: $isAnnouncement,'
        'commentsCount: $commentsCount,'
        'reactionsCount: $reactionsCount,'
        'myReactions: $myReactions,'
        'reactions: $reactions,'
        'commenters: $commenters,'
        'properties: $properties,'
        'createdAt: $createdAt,'
        'mentions: $mentions,'
        'source: $source,'
        'status: $status,'
        'poll: $poll'
        '}';
  }
}

==> getsocial_flutter_sdk-7.8.1.tar.gz: lib/communities/activity.dart <==
import '../common/media_attachment.dart';
import '../src/utils.dart';
import '../usermanagement/user.dart';
import 'activitybutton.dart';
import 'communitiesentity.dart';
import 'mention.dart';
import 'poll.dart';
import 'userreactions.dart';

/// Describe Activity object.
class GetSocialActivity {
  GetSocialActivity.fromJSON(Map<String, dynamic> json)
      : id = json['id'],
        text = json['text'],
        author = User.fromJSON(json['author']),
        attachments = Utils.createList(json['attachments'],
            (jsonMap) => MediaAttachment.fromJSON(jsonMap)),
        button = json['button'] == null
            ? null
            : ActivityButton.fromJSON(json['button']),
        type = json['type'],
        isAnnouncement = json['announcement'],
        commentsCount = json['commentsCount'],
        reactionsCount = Utils.createStringIntMap(json['reactionsCount']),
        myReactions = Utils.createStringList(json['myReactions']),
        reactions = Utils.createList(
            json['reactions'], (jsonMap) => UserReactions.fromJSON(jsonMap)),
        commenters = Utils.createList(
            json['commenters'], (jsonMap) => User.fromJSON(jsonMap)),
        properties = Utils.createStringStringMap(json['properties']),
        createdAt = json['createdAt'],
        mentions = Utils.createList(
            json['mentions'], (jsonMap) => Mention.fromJSON(jsonMap)),
        source = CommunitiesEntity.fromJSON(json['source']),
        status = json['status'],
        poll = json['poll'] == null ? null : Poll.fromJSON(json['poll']),
        popularity =
            json['popularity'] == null ? 0 : json['popularity'].toDouble();

  String id;
  String? text;
  User author;
  List<MediaAttachment> attachments;
  ActivityButton? button;
  String type;
  bool isAnnouncement;
  int commentsCount;
  Map<String, int> reactionsCount;
  List<String> myReactions;
  List<UserReactions> reactions;
  List<User> commenters;
  Map<String, String> properties;
  int createdAt;
  List<Mention> mentions;
  CommunitiesEntity source;
  String status;
  Poll? poll;
  double popularity = 0;

  @override
  String toString() {
    var authorId = this.author.userId;
    return 'Activity{'
        'id: $id, '
        'text: $text,'
        'author: $authorId,'
        'mediaAttachments: $attachments,'
        'button: $button,'
        'type: $type,'
        'isAnnouncement: $isAnnouncement,'
        'commentsCount: $commentsCount,'
        'reactionsCount: $reactionsCount,'
        'myReactions: $myReactions,'
        'reactions: $reactions,'
        'commenters: $commenters,'
        'properties: $properties,'
        'createdAt: $createdAt,'
        'mentions: $mentions,'
        'source: $source,'
        'status: $status,'
        'poll: $poll,'
        'popularity: $popularity'
        '}';
  }
}
